# encoding:utf-8
# 消息队列线程池工人数
msg_queue_max_num = 30
# 此处为消息队列配置
mq = {
    'remote_center': False
    # 'remote_address': '127.0.0.1',
    # 'remote_port': 58800
}
# 消息队列调试标识
msg_queue_debug = False
