blueprint_path=['/routes']
db_pool_exe_time=False
debug_trace=False
error_info='HTML'
host='127.0.0.1'
ip_count=False
mq={'remote_center': False}
msg_queue_debug=False
msg_queue_max_num=30
pool_conn_num=5
port=443
project_root='D:/Desktop/dophon-properties/dophon_properties'
pydc_database='db'
pydc_host='localhost'
pydc_password='root'
pydc_port=3306
pydc_user='root'
pydc_xmlupdate_sech=False
server_gevented=False
server_processes=1
server_threaded=False
ssl_context='adhoc'
